@@ -25,11 +25,18 @@ sub list
 package FusqlFS::Backend::PgSQL::Role::Owner;
 use parent 'FusqlFS::Artifact';
 
-our %relkinds = qw(
-    r TABLE
-    i INDEX
-    S SEQUENCE
-    v VIEW
+our %relkinds = (
+    r  => [ qw(TABLE rel) ],
+    i  => [ qw(INDEX rel) ],
+    S  => [ qw(SEQUENCE rel) ],
+    v  => [ qw(VIEW rel) ],
+
+    _F => [ qw(FUNCTION pro) ],
+);
+
+our %reltables = qw(
+    rel pg_class
+    pro pg_proc
 );
 
 sub new
@@ -37,11 +44,16 @@ sub new
     my $class = shift;
     my $relkind = shift;
     my $depth = 0+shift;
+
+    my ($kind, $rel) = @{$relkinds{$relkind}};
+    my $table = $reltables{$rel};
+    my $kindclause = $table eq 'pg_class'? "AND relkind = '$relkind'": "";
+
     my $self = {};
 
     $self->{depth} = '../' x $depth;
-    $self->{get_expr} = $class->expr("SELECT pg_catalog.pg_get_userbyid(relowner) FROM pg_catalog.pg_class WHERE relname = ? AND relkind = '$relkind'");
-    $self->{store_expr} = "ALTER $relkinds{$relkind} \"%s\" OWNER TO \"%s\"";
+    $self->{get_expr} = $class->expr("SELECT pg_catalog.pg_get_userbyid(${rel}owner) FROM pg_catalog.$table WHERE ${rel}name = ? $kindclause");
+    $self->{store_expr} = "ALTER ${kind} \"%s\" OWNER TO \"%s\"";
 
     bless $self, $class;
 }
@@ -50,6 +62,7 @@ sub get
 {
     my $self = shift;
     my $name = pop;
+    $name = $1 if $name =~ /^([a-zA-Z0-9_]+)/;
     my $owner = $self->all_col($self->{get_expr}, $name);
     return \"$self->{depth}roles/$owner->[0]" if $owner;
 }
