@@ -3,6 +3,17 @@ use v5.10.0;
 
 package FusqlFS::Cache::Base;
 
+=begin testing new
+
+#!noinst
+
+my $test = $_tcls->new();
+isa_ok $test, 'HASH';
+is tied($test), undef;
+
+=end testing
+=cut
+
 sub new
 {
     my $class = shift;
